#' @rdname geom_TLRline
#' @aliases tline
#' @export
Tline <- function(Tintercept=NULL,...){geom_Tline(Tintercept=Tintercept,...)}
tline <- Tline

#' @rdname geom_TLRline
#' @aliases lline
#' @export
Lline <- function(Lintercept=NULL,...){geom_Lline(Lintercept=Lintercept,...)}
lline <- Lline

#' @rdname geom_TLRline
#' @aliases rline
#' @export
Rline <- function(Rintercept=NULL,...){geom_Rline(Rintercept=Rintercept,...)}
rline <- Rline